pub struct LockOrder {Show 15 fields
pub fee_vault: Pubkey,
pub taker: Pubkey,
pub deprecated_cosigner: Option<Pubkey>,
pub order_state: Pubkey,
pub order_vault: Pubkey,
pub maker: Pubkey,
pub margin_account: Option<Pubkey>,
pub maker_broker: Option<Pubkey>,
pub taker_broker: Option<Pubkey>,
pub token_program: Pubkey,
pub system_program: Pubkey,
pub associated_token_program: Pubkey,
pub tensorswap_program: Pubkey,
pub tlock_program: Pubkey,
pub order_nft_receipt: Option<Pubkey>,
}Expand description
Accounts.
Fields
fee_vault: Pubkeytaker: Pubkeydeprecated_cosigner: Option<Pubkey>Deprecated: In place for backwards compatibility, but can be left to default to program_id.
order_state: Pubkeyorder_vault: Pubkeymaker: Pubkeymargin_account: Option<Pubkey>maker_broker: Option<Pubkey>taker_broker: Option<Pubkey>token_program: Pubkeysystem_program: Pubkeyassociated_token_program: Pubkeytensorswap_program: Pubkeytlock_program: Pubkeyorder_nft_receipt: Option<Pubkey>The NFT deposit receipt account, which tracks an NFT to the order state it was deposited to.
Implementations
Sourceimpl LockOrder
impl LockOrder
pub fn instruction(&self, args: LockOrderInstructionArgs) -> Instruction
pub fn instruction_with_remaining_accounts( &self, args: LockOrderInstructionArgs, remaining_accounts: &[AccountMeta], ) -> Instruction