pub struct LockOrderCpi<'a, 'b> {Show 17 fields
pub __program: &'b AccountInfo<'a>,
pub fee_vault: &'b AccountInfo<'a>,
pub taker: &'b AccountInfo<'a>,
pub deprecated_cosigner: Option<&'b AccountInfo<'a>>,
pub order_state: &'b AccountInfo<'a>,
pub order_vault: &'b AccountInfo<'a>,
pub maker: &'b AccountInfo<'a>,
pub margin_account: Option<&'b AccountInfo<'a>>,
pub maker_broker: Option<&'b AccountInfo<'a>>,
pub taker_broker: Option<&'b AccountInfo<'a>>,
pub token_program: &'b AccountInfo<'a>,
pub system_program: &'b AccountInfo<'a>,
pub associated_token_program: &'b AccountInfo<'a>,
pub tensorswap_program: &'b AccountInfo<'a>,
pub tlock_program: &'b AccountInfo<'a>,
pub order_nft_receipt: Option<&'b AccountInfo<'a>>,
pub __args: LockOrderInstructionArgs,
}Expand description
lock_order CPI instruction.
Fields
__program: &'b AccountInfo<'a>The program to invoke.
fee_vault: &'b AccountInfo<'a>taker: &'b AccountInfo<'a>deprecated_cosigner: Option<&'b AccountInfo<'a>>Deprecated: In place for backwards compatibility, but can be left to default to program_id.
order_state: &'b AccountInfo<'a>order_vault: &'b AccountInfo<'a>maker: &'b AccountInfo<'a>margin_account: Option<&'b AccountInfo<'a>>maker_broker: Option<&'b AccountInfo<'a>>taker_broker: Option<&'b AccountInfo<'a>>token_program: &'b AccountInfo<'a>system_program: &'b AccountInfo<'a>associated_token_program: &'b AccountInfo<'a>tensorswap_program: &'b AccountInfo<'a>tlock_program: &'b AccountInfo<'a>order_nft_receipt: Option<&'b AccountInfo<'a>>The NFT deposit receipt account, which tracks an NFT to the order state it was deposited to.
__args: LockOrderInstructionArgsThe arguments for the instruction.
Implementations
Sourceimpl<'a, 'b> LockOrderCpi<'a, 'b>
impl<'a, 'b> LockOrderCpi<'a, 'b>
pub fn new( program: &'b AccountInfo<'a>, accounts: LockOrderCpiAccounts<'a, 'b>, args: LockOrderInstructionArgs, ) -> Self
pub fn invoke(&self) -> ProgramResult
pub fn invoke_with_remaining_accounts( &self, remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult
pub fn invoke_signed_with_remaining_accounts( &self, signers_seeds: &[&[&[u8]]], remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult