LockOrderCpiAccounts

Struct LockOrderCpiAccounts 

pub struct LockOrderCpiAccounts<'a, 'b> {
Show 15 fields pub fee_vault: &'b AccountInfo<'a>, pub taker: &'b AccountInfo<'a>, pub deprecated_cosigner: Option<&'b AccountInfo<'a>>, pub order_state: &'b AccountInfo<'a>, pub order_vault: &'b AccountInfo<'a>, pub maker: &'b AccountInfo<'a>, pub margin_account: Option<&'b AccountInfo<'a>>, pub maker_broker: Option<&'b AccountInfo<'a>>, pub taker_broker: Option<&'b AccountInfo<'a>>, pub token_program: &'b AccountInfo<'a>, pub system_program: &'b AccountInfo<'a>, pub associated_token_program: &'b AccountInfo<'a>, pub tensorswap_program: &'b AccountInfo<'a>, pub tlock_program: &'b AccountInfo<'a>, pub order_nft_receipt: Option<&'b AccountInfo<'a>>,
}
lock_order CPI accounts.

Fields

fee_vault: &'b AccountInfo<'a>taker: &'b AccountInfo<'a>deprecated_cosigner: Option<&'b AccountInfo<'a>>

Deprecated: In place for backwards compatibility, but can be left to default to program_id.

order_state: &'b AccountInfo<'a>order_vault: &'b AccountInfo<'a>maker: &'b AccountInfo<'a>margin_account: Option<&'b AccountInfo<'a>>maker_broker: Option<&'b AccountInfo<'a>>taker_broker: Option<&'b AccountInfo<'a>>token_program: &'b AccountInfo<'a>system_program: &'b AccountInfo<'a>associated_token_program: &'b AccountInfo<'a>tensorswap_program: &'b AccountInfo<'a>tlock_program: &'b AccountInfo<'a>order_nft_receipt: Option<&'b AccountInfo<'a>>

The NFT deposit receipt account, which tracks an NFT to the order state it was deposited to.