pub struct LockOrderInstructionArgs {
pub price: u64,
pub nonce: u32,
pub apr_bps: u32,
pub duration_sec: u32,
pub early_close: bool,
}Fields
price: u64nonce: u32apr_bps: u32duration_sec: u32early_close: boolTrait Implementations
Sourceimpl BorshDeserialize for LockOrderInstructionArgs
impl BorshDeserialize for LockOrderInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for LockOrderInstructionArgs
impl Clone for LockOrderInstructionArgs
Sourcefn clone(&self) -> LockOrderInstructionArgs
fn clone(&self) -> LockOrderInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LockOrderInstructionArgs
impl Debug for LockOrderInstructionArgs
impl Eq for LockOrderInstructionArgs
Sourceimpl PartialEq for LockOrderInstructionArgs
impl PartialEq for LockOrderInstructionArgs
Sourcefn eq(&self, other: &LockOrderInstructionArgs) -> bool
fn eq(&self, other: &LockOrderInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LockOrderInstructionArgs