pub struct WithdrawCollateralCompressedCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for WithdrawCollateralCompressed via CPI.
Accounts:
[writable, signer]signer[writable]order_state[writable]order_vault[]maker[writable]taker[writable]destination[]system[]tlock_program[]tree_authority[writable]merkle_tree[]log_wrapper[]compression_program[]bubblegum_program[]whitelist[writable]order_nft_receipt
Implementations
Sourceimpl<'a, 'b> WithdrawCollateralCompressedCpiBuilder<'a, 'b>
impl<'a, 'b> WithdrawCollateralCompressedCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn signer(&mut self, signer: &'b AccountInfo<'a>) -> &mut Self
pub fn order_state(&mut self, order_state: &'b AccountInfo<'a>) -> &mut Self
pub fn order_vault(&mut self, order_vault: &'b AccountInfo<'a>) -> &mut Self
pub fn maker(&mut self, maker: &'b AccountInfo<'a>) -> &mut Self
pub fn taker(&mut self, taker: &'b AccountInfo<'a>) -> &mut Self
pub fn destination(&mut self, destination: &'b AccountInfo<'a>) -> &mut Self
pub fn system(&mut self, system: &'b AccountInfo<'a>) -> &mut Self
pub fn tlock_program(&mut self, tlock_program: &'b AccountInfo<'a>) -> &mut Self
pub fn merkle_tree(&mut self, merkle_tree: &'b AccountInfo<'a>) -> &mut Self
pub fn log_wrapper(&mut self, log_wrapper: &'b AccountInfo<'a>) -> &mut Self
pub fn compression_program( &mut self, compression_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn bubblegum_program( &mut self, bubblegum_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn whitelist(&mut self, whitelist: &'b AccountInfo<'a>) -> &mut Self
pub fn order_nft_receipt( &mut self, order_nft_receipt: &'b AccountInfo<'a>, ) -> &mut Self
Sourcepub fn to_maker(&mut self, to_maker: bool) -> &mut Self
pub fn to_maker(&mut self, to_maker: bool) -> &mut Self
[optional argument, defaults to 'true']
pub fn root(&mut self, root: [u8; 32]) -> &mut Self
pub fn nonce(&mut self, nonce: u64) -> &mut Self
pub fn index(&mut self, index: u32) -> &mut Self
pub fn meta_args(&mut self, meta_args: TMetadataArgs) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult