pub struct WithdrawCollateralCompressedInstructionArgs {
pub to_maker: bool,
pub root: [u8; 32],
pub nonce: u64,
pub index: u32,
pub meta_args: TMetadataArgs,
}Fields
to_maker: boolroot: [u8; 32]nonce: u64index: u32meta_args: TMetadataArgsTrait Implementations
Sourceimpl BorshDeserialize for WithdrawCollateralCompressedInstructionArgswhere
bool: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u64: BorshDeserialize,
u32: BorshDeserialize,
TMetadataArgs: BorshDeserialize,
impl BorshDeserialize for WithdrawCollateralCompressedInstructionArgswhere
bool: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u64: BorshDeserialize,
u32: BorshDeserialize,
TMetadataArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for WithdrawCollateralCompressedInstructionArgswhere
bool: BorshSerialize,
[u8; 32]: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
TMetadataArgs: BorshSerialize,
impl BorshSerialize for WithdrawCollateralCompressedInstructionArgswhere
bool: BorshSerialize,
[u8; 32]: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
TMetadataArgs: BorshSerialize,
Sourceimpl Clone for WithdrawCollateralCompressedInstructionArgs
impl Clone for WithdrawCollateralCompressedInstructionArgs
Sourcefn clone(&self) -> WithdrawCollateralCompressedInstructionArgs
fn clone(&self) -> WithdrawCollateralCompressedInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for WithdrawCollateralCompressedInstructionArgs
Sourceimpl PartialEq for WithdrawCollateralCompressedInstructionArgs
impl PartialEq for WithdrawCollateralCompressedInstructionArgs
Sourcefn eq(&self, other: &WithdrawCollateralCompressedInstructionArgs) -> bool
fn eq(&self, other: &WithdrawCollateralCompressedInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WithdrawCollateralCompressedInstructionArgs